library(igraph)
g = read.graph(file="dolphin.gml", format="gml")
male = V(g)$sex == "M"
female = V(g)$sex == "F"
unknown = V(g)$sex == "U"
V(g)$color = "white"


shinyServer(
  function(input, output) {

    coords = reactive({switch(input$layout, 
                       "Force-directed" = layout.fruchterman.reingold(g),
                       "Circle" = layout.circle(g),
                       "Sphere" = layout.sphere(g),
                       "Tree" = layout.reingold.tilford(g),
                       "Random" = layout.random(g))
                    })
    
    output$net = renderPlot({
      if("Male" %in% input$sex) V(g)[male]$color = "blue"
      if("Female" %in% input$sex) V(g)[female]$color = "pink"
      if("Unknown" %in% input$sex) V(g)[unknown]$color = "green"
 
      plot(g, layout=coords(), vertex.label=NA, vertex.size=7)
    })
  }
)